@@ -3,7 +3,7 @@
 # HeeFramework
 # @Time    : 2020/11/10 15:06
 # @Author  : yanhu.zou
-__version__ = "1.0.33"
+__version__ = "1.0.35"
 
 import datetime
 import decimal
@@ -212,12 +212,16 @@ class HeeApplication:
                 if subpath.endswith('__pycache__'):
                     continue
 
-                if subpath == 'static':
+                if subpath == 'static':    # 一般为python的静态文件目录，直接跳过
                     continue
 
-                if subpath == 'template':
+                if subpath == 'template':  # 一般为python的模板目录，直接跳过
                     continue
 
+                if subpath == 'venv':   # 一般为python的虚拟环境目录，直接跳过
+                    continue
+
+
                 self.scan_and_load_submod(path + "/" + subpath)
 
         # If it is a python file, load the processing module
@@ -406,7 +410,6 @@ class HeeRestApplication(HeeApplication):
                 submod = self.hee_container.submods[submod_name]
                 if hasattr(submod, 'mapping'):
                     self.heeFlask.register_blueprint(submod.mapping)
-
                 if hasattr(submod, 'web'):
                     submod.web = self.web
                 pass
@@ -563,9 +566,6 @@ class HeeWebApplication(HeeRestApplication):
         if not os.path.exists(root_path + "/static/"):
             os.mkdir(root_path + "/static/")
             log_.info("The static dir does not exists, create it.")
-        if not os.path.exists("template/"):
-            os.mkdir("template")
-            log_.info("The template dir does not exists, create it.")
 
 
 class HeeSchedApplication(HeeApplication):
