@@ -14,7 +14,7 @@ import pymysql
 import pymysql.cursors
 from dbutils.pooled_db import PooledDB
 
-logger_ = log4p.GetLogger(logger_name=__name__, config="config/log4p.json")
+logger_ = log4p.GetLogger(logger_name=__name__, logging_level="INFO", config="config/log4p.json")
 log = logger_.logger
 """
     容易出错的点：
@@ -58,7 +58,7 @@ class DbMySQL(RDB):
 
             # 参数格式化
             final_sql = self._build_sql(sql, params)
-            log.debug("final_sql: " + final_sql)
+            log.info("final_sql: " + final_sql)
 
             cursor.execute(final_sql)
             results = cursor.fetchall()
@@ -79,7 +79,7 @@ class DbMySQL(RDB):
 
             # 参数格式化
             final_sql = self._build_sql(sql, params)
-            log.debug("final_sql: " + final_sql)
+            log.info("final_sql: " + final_sql)
 
             cursor.execute(final_sql)
             results = cursor.fetchone()
@@ -100,7 +100,7 @@ class DbMySQL(RDB):
 
             # 参数格式化
             final_sql = self._build_sql(sql, params)
-            log.debug("final_sql: " + final_sql)
+            log.info("final_sql: " + final_sql)
 
             row = cursor.execute(final_sql)
             conn.commit()
@@ -131,7 +131,7 @@ class DbMySQL(RDB):
                 final_sql = final_sql.replace('#{' + param_name + '}', param_value)
             # None
             elif param_value is None:
-                final_sql = final_sql.replace('#{' + param_name + '}', '\'\'')
+                final_sql = final_sql.replace('#{' + param_name + '}', 'null')
             # dict
             elif isinstance(param_value, dict):
                 final_sql = final_sql.replace('#{' + param_name + '}', '\"' + param_value.__str__() + '\"')
